@@ -7,9 +7,9 @@ use booleans::*;
 
 /// Produces a Church-encoded zero.
 ///
-/// zero := λfx.x = λ λ 1
-/// # Example
+/// ZERO := λfx.x = λ λ 1
 ///
+/// # Example
 /// ```
 /// use lambda_calculus::arithmetic::zero;
 ///
@@ -20,7 +20,7 @@ pub fn zero() -> Term { abs(abs(Var(1))) }
 /// Applied to a Church-encoded number it produces a Church-encoded boolean, indicating whether its
 /// argument is equal to zero.
 ///
-/// is_zero := λn.n (λx.false) true =  λ 1 (λ false) true
+/// IS_ZERO := λn.n (λx.FALSE) TRUE =  λ 1 (λ FALSE) TRUE
 ///
 /// # Example
 /// ```
@@ -34,7 +34,7 @@ pub fn is_zero() -> Term { abs(Var(1).app(abs(fls())).app(tru())) }
 
 /// Produces a Church-encoded one.
 ///
-/// one := λfx.f x = λ λ 2 1
+/// ONE := λfx.f x = λ λ 2 1
 ///
 /// # Example
 /// ```
@@ -46,7 +46,7 @@ pub fn one() -> Term { abs(abs(Var(2).app(Var(1)))) }
 
 /// Applied to a Church-encoded number it produces its successor.
 ///
-/// succ := λnfx.f (n f x) = λ λ λ 2 (3 2 1)
+/// SUCC := λnfx.f (n f x) = λ λ λ 2 (3 2 1)
 ///
 /// # Example
 /// ```
@@ -59,7 +59,7 @@ pub fn succ() -> Term { abs(abs(abs(Var(2).app(Var(3).app(Var(2)).app(Var(1)))))
 
 /// Applied to two Church-encoded numbers it produces their sum.
 ///
-/// plus := λmnfx.m f (n f x) = λ λ λ λ 4 2 (3 2 1)
+/// PLUS := λmnfx.m f (n f x) = λ λ λ λ 4 2 (3 2 1)
 ///
 /// # Example
 /// ```
@@ -72,7 +72,7 @@ pub fn plus() -> Term { abs(abs(abs(abs(Var(4).app(Var(2)).app(Var(3).app(Var(2)
 
 /// Applied to two Church-encoded numbers it produces their product.
 ///
-/// mult := λmnf.m (n f) = λ λ λ 3 (2 1)
+/// MULT := λmnf.m (n f) = λ λ λ 3 (2 1)
 ///
 /// # Example
 /// ```
@@ -85,7 +85,7 @@ pub fn mult() -> Term { abs(abs(abs(Var(3).app(Var(2).app(Var(1)))))) }
 
 /// Applied to two Church-encoded numbers it raises the first one to the power of the second one.
 ///
-/// pow := λbe.e b = λ λ 1 2
+/// POW := λbe.e b = λ λ 1 2
 ///
 /// # Example
 /// ```
@@ -98,7 +98,7 @@ pub fn pow() -> Term { abs(abs(Var(1).app(Var(2)))) }
 
 /// Applied to a Church-encoded number it produces its predecessor.
 ///
-/// pred := λnfx.n (λgh.h (g f)) (λu.x) (λu.u) = λ λ λ 3 (λ λ 1 (2 4)) (λ 2) (λ 1)
+/// PRED := λnfx.n (λgh.h (g f)) (λu.x) (λu.u) = λ λ λ 3 (λ λ 1 (2 4)) (λ 2) (λ 1)
 ///
 /// # Example
 /// ```
@@ -107,11 +107,18 @@ pub fn pow() -> Term { abs(abs(Var(1).app(Var(2)))) }
 ///
 /// assert_eq!(normalize(pred().app(one())), zero());
 /// ```
-pub fn pred() -> Term { abs(abs(abs(Var(3).app(abs(abs(Var(1).app(Var(2).app(Var(4)))))).app(abs(Var(2))).app(abs(Var(1)))))) }
+pub fn pred() -> Term {
+	abs(abs(abs(
+		Var(3)
+		.app(abs(abs(Var(1).app(Var(2).app(Var(4))))))
+		.app(abs(Var(2)))
+		.app(abs(Var(1)))
+	)))
+}
 
 /// Applied to two Church-encoded numbers it subtracts the second one from the first one.
 ///
-/// sub := λmn.n pred m = λ λ 1 pred 2
+/// SUB := λmn.n PRED m = λ λ 1 PRED 2
 ///
 /// # Example
 /// ```
@@ -123,34 +130,124 @@ pub fn pred() -> Term { abs(abs(abs(Var(3).app(abs(abs(Var(1).app(Var(2).app(Var
 pub fn sub() -> Term { abs(abs(Var(1).app(pred()).app(Var(2)))) }
 
 /// Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its
-/// first argument is less or egual to the second one.
+/// first argument is less than the second one.
 ///
-/// leq := λmn.is_zero (sub m n) = λ λ is_zero (sub 2 1)
+/// LT := λab.NOT (LEQ b a) = λ λ NOT (LEQ 1 2)
+///
+/// # Example
+/// ```
+/// use lambda_calculus::arithmetic::{zero, one, lt};
+/// use lambda_calculus::booleans::{tru, fls};
+/// use lambda_calculus::reduction::normalize;
+///
+/// assert_eq!(normalize(lt().app(zero()).app(zero())), fls());
+/// assert_eq!(normalize(lt().app(one()).app(one())),   fls());
+/// assert_eq!(normalize(lt().app(zero()).app(one())),  tru());
+/// assert_eq!(normalize(lt().app(one()).app(zero())),  fls());
+/// ```
+pub fn lt() -> Term { abs(abs(not().app(leq().app(Var(1)).app(Var(2))))) }
+
+/// Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its
+/// first argument is less than or egual to the second one.
+///
+/// LEQ := λmn.IS_ZERO (SUB m n) = λ λ IS_ZERO (SUB 2 1)
 ///
 /// # Example
 /// ```
 /// use lambda_calculus::arithmetic::{zero, one, leq};
-/// use lambda_calculus::booleans::tru;
+/// use lambda_calculus::booleans::{tru, fls};
 /// use lambda_calculus::reduction::normalize;
 ///
-/// assert_eq!(normalize(leq().app(zero()).app(one())), tru());
+/// assert_eq!(normalize(leq().app(zero()).app(zero())), tru());
+/// assert_eq!(normalize(leq().app(one()).app(one())),   tru());
+/// assert_eq!(normalize(leq().app(zero()).app(one())),  tru());
+/// assert_eq!(normalize(leq().app(one()).app(zero())),  fls());
 /// ```
 pub fn leq() -> Term { abs(abs(is_zero().app(sub().app(Var(2)).app(Var(1))))) }
 
 /// Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its
 /// first argument is egual to the second one.
 ///
-/// eq := λmn.and (leq m n) (leq n m) = λ λ and (leq 2 1) (leq 1 2)
+/// EQ := λmn.AND (LEQ m n) (LEQ n m) = λ λ AND (LEQ 2 1) (LEQ 1 2)
 ///
 /// # Example
 /// ```
-/// use lambda_calculus::arithmetic::{one, eq};
-/// use lambda_calculus::booleans::tru;
+/// use lambda_calculus::arithmetic::{zero, one, eq};
+/// use lambda_calculus::booleans::{tru, fls};
 /// use lambda_calculus::reduction::normalize;
 ///
-/// assert_eq!(normalize(eq().app(one()).app(one())), tru());
+/// assert_eq!(normalize(eq().app(zero()).app(zero())), tru());
+/// assert_eq!(normalize(eq().app(one()).app(one())),   tru());
+/// assert_eq!(normalize(eq().app(zero()).app(one())),  fls());
+/// assert_eq!(normalize(eq().app(one()).app(zero())),  fls());
 /// ```
-pub fn eq() -> Term { abs(abs(and().app(leq().app(Var(2)).app(Var(1))).app(leq().app(Var(1)).app(Var(2))))) }
+pub fn eq() -> Term {
+	abs(abs(
+		and()
+		.app(leq().app(Var(2)).app(Var(1)))
+		.app(leq().app(Var(1)).app(Var(2)))
+	))
+}
+
+/// Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its
+/// first argument is not egual to the second one.
+///
+/// NEQ := λab.OR (NOT (LEQ a b)) (NOT (LEQ b a)) = λ λ OR (NOT (LEQ 2 1)) (NOT (LEQ 1 2))
+///
+/// # Example
+/// ```
+/// use lambda_calculus::arithmetic::{zero, one, neq};
+/// use lambda_calculus::booleans::{tru, fls};
+/// use lambda_calculus::reduction::normalize;
+///
+/// assert_eq!(normalize(neq().app(zero()).app(zero())), fls());
+/// assert_eq!(normalize(neq().app(one()).app(one())),   fls());
+/// assert_eq!(normalize(neq().app(zero()).app(one())),  tru());
+/// assert_eq!(normalize(neq().app(one()).app(zero())),  tru());
+/// ```
+pub fn neq() -> Term {
+	abs(abs(
+		or()
+		.app(not().app(leq().app(Var(2)).app(Var(1))))
+		.app(not().app(leq().app(Var(1)).app(Var(2))))
+	))
+}
+
+/// Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its
+/// first argument is greater than or egual to the second one.
+///
+/// GEQ := λab.LEQ b a = λ λ LEQ 1 2
+///
+/// # Example
+/// ```
+/// use lambda_calculus::arithmetic::{zero, one, geq};
+/// use lambda_calculus::booleans::{tru, fls};
+/// use lambda_calculus::reduction::normalize;
+///
+/// assert_eq!(normalize(geq().app(zero()).app(zero())), tru());
+/// assert_eq!(normalize(geq().app(one()).app(one())),   tru());
+/// assert_eq!(normalize(geq().app(zero()).app(one())),  fls());
+/// assert_eq!(normalize(geq().app(one()).app(zero())),  tru());
+/// ```
+pub fn geq() -> Term { abs(abs(leq().app(Var(1)).app(Var(2)))) }
+
+/// Applied to two Church-encoded numbers it returns a Church-encoded boolean indicating whether its
+/// first argument is greater than the second one.
+///
+/// GT := λab.NOT (LEQ a b) = λ λ NOT (LEQ 2 1)
+///
+/// # Example
+/// ```
+/// use lambda_calculus::arithmetic::{zero, one, gt};
+/// use lambda_calculus::booleans::{tru, fls};
+/// use lambda_calculus::reduction::normalize;
+///
+/// assert_eq!(normalize(gt().app(zero()).app(zero())), fls());
+/// assert_eq!(normalize(gt().app(one()).app(one())),   fls());
+/// assert_eq!(normalize(gt().app(zero()).app(one())),  fls());
+/// assert_eq!(normalize(gt().app(one()).app(zero())),  tru());
+/// ```
+pub fn gt() -> Term { abs(abs(not().app(leq().app(Var(2)).app(Var(1))))) }
 
 impl Term {
 	/// Returns the value of a Church-encoded number.
@@ -299,16 +396,4 @@ mod test {
 		assert_eq!(normalize(pred().app(one())), zero());
 		assert_eq!(normalize(pred().app(to_cnum(5))), to_cnum(4));
 	}
-
-	#[test]
-	fn church_comparison() {
-		assert_eq!(normalize(leq().app(zero()).app(zero())), tru());
-		assert_eq!(normalize(leq().app(zero()).app(one())),  tru());
-		assert_eq!(normalize(leq().app(one()).app(zero())),  fls());
-
-		assert_eq!(normalize(eq().app(zero()).app(zero())), tru());
-		assert_eq!(normalize(eq().app(zero()).app(one())),  fls());
-		assert_eq!(normalize(eq().app(one()).app(zero())),  fls());
-		// TODO: add lt, gt, geq
-	}
-}
\ No newline at end of file
+}
